@@ -10,8 +10,10 @@ import json
 import pymssql
 import sys
 
+from email import encoders
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
+from email.mime.base import MIMEBase
 from smtplib import SMTP, SMTPException
 from google.cloud.bigquery import Client, LoadJobConfig, DatasetReference, TableReference
 from google.cloud.bigquery import SchemaField as sf
@@ -23,6 +25,7 @@ from CsPy_Uploading.classes import JobSettings
 from CsPy_Uploading.classes import UploadJob
 from CsPy_Uploading.classes import DownloadJob
 from CsPy_Uploading.classes import Account
+from CsPy_Uploading.classes import Email
 from CsPy_Uploading.classes import GeneralScriptError
 from CsPy_Uploading.classes import InputError
 from CsPy_Uploading.classes import ColumnMissingError
@@ -82,5 +85,5 @@ Functions:
 Misc variables:
 
     __version__
-    1.0.4
+    1.0.7
 """
\ No newline at end of file
